pub struct StatsOutput {
pub ok: bool,
pub components: Value,
pub facts: Option<u64>,
pub chunks: Option<u64>,
pub documents: Option<u64>,
pub sessions: Option<u64>,
pub messages: Option<u64>,
pub graph_edges: Option<usize>,
pub db_size_bytes: Option<u64>,
pub db_size_mb: Option<f64>,
pub embedding_model: Option<String>,
pub embedding_dimensions: Option<usize>,
}Expand description
Typed output for sm_stats — provides outputSchema with type: “object” for MCP.
Fields
ok: boolcomponents: Valuefacts: Option<u64>chunks: Option<u64>documents: Option<u64>sessions: Option<u64>messages: Option<u64>graph_edges: Option<usize>db_size_bytes: Option<u64>db_size_mb: Option<f64>embedding_model: Option<String>embedding_dimensions: Option<usize>Trait Implementations
Sourceimpl Debug for StatsOutput
impl Debug for StatsOutput
Sourceimpl<'de> Deserialize<'de> for StatsOutput
impl<'de> Deserialize<'de> for StatsOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatsOutput
impl JsonSchema for StatsOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StatsOutput
impl RefUnwindSafe for StatsOutput
impl Send for StatsOutput
impl Sync for StatsOutput
impl Unpin for StatsOutput
impl UnsafeUnpin for StatsOutput
impl UnwindSafe for StatsOutput