pub struct StructuredOutput {
pub fields: BTreeMap<String, Value>,
}Expand description
Schema-backed structured output shared by heterogeneous MCP tools.
Existing object responses retain their top-level wire shape through
flatten. Scalar and array results are wrapped under value, because MCP
requires structured tool outputs to have an object root schema.
Fields
fields: BTreeMap<String, Value>Trait Implementations
Sourceimpl Clone for StructuredOutput
impl Clone for StructuredOutput
Sourcefn clone(&self) -> StructuredOutput
fn clone(&self) -> StructuredOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructuredOutput
impl Debug for StructuredOutput
Sourceimpl<'de> Deserialize<'de> for StructuredOutput
impl<'de> Deserialize<'de> for StructuredOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StructuredOutput
impl JsonSchema for StructuredOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StructuredOutput
impl RefUnwindSafe for StructuredOutput
impl Send for StructuredOutput
impl Sync for StructuredOutput
impl Unpin for StructuredOutput
impl UnsafeUnpin for StructuredOutput
impl UnwindSafe for StructuredOutput